Anomaly detectors — skchange

Skip to main content
`Ctrl`+`K`

# Anomaly detectors

## Base

`CollectiveAnomalyDetector`() | Base class for collective anomaly detectors.
`SubsetCollectiveAnomalyDetector`() | Base class for subset collective anomaly detectors.
`PointAnomalyDetector`() | Base class for point anomaly detectors.

## Collective anomaly detectors

`Capa`([saving, collective_penalty_scale, ...]) | Collective and point anomaly detection.
`CircularBinarySegmentation`([score, ...]) | Circular binary segmentation algorithm for multiple collective anomaly detection.
`MoscoreAnomaly`([score, min_anomaly_length, ...]) | Moving score algorithm for multiple collective anomaly detection.
`StatThresholdAnomaliser`(change_detector, ...) | Anomaly detection based on thresholding the values of segment statistics.

## Subset collective anomaly detectors

`Mvcapa`([saving, collective_penalty, ...]) | Subset multivariate collective and point anomaly detection.